@@ -30,6 +30,7 @@
 #include "lib/util/dlinklist.h"
 #include "lib/util/debug.h"
 #include "lib/util/samba_util.h"
+#include "lib/util/sys_rw.h"
 #include "lib/util/util_process.h"
 
 #include "ctdb_private.h"
@@ -1854,10 +1855,9 @@ int ctdb_start_revoke_ro_record(struct ctdb_context *ctdb, struct ctdb_db_contex
 	if (rc->child == 0) {
 		char c = 0;
 		close(rc->fd[0]);
-		debug_extra = talloc_asprintf(NULL, "revokechild-%s:", ctdb_db->db_name);
 
 		prctl_set_comment("ctdb_revokechild");
-		if (switch_from_server_to_client(ctdb, "revokechild-%s", ctdb_db->db_name) != 0) {
+		if (switch_from_server_to_client(ctdb) != 0) {
 			DEBUG(DEBUG_ERR,("Failed to switch from server to client for revokechild process\n"));
 			c = 1;
 			goto child_finished;
