@@ -601,7 +601,7 @@ static WERROR bkrp_client_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 	blob.length = r->in.data_in_len;
 
 	if (r->in.data_in_len < 4 || r->in.data_in == NULL) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	/*
@@ -618,7 +618,7 @@ static WERROR bkrp_client_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 	ndr_err = ndr_pull_struct_blob(&blob, mem_ctx, &uncrypt_request,
 				       (ndr_pull_flags_fn_t)ndr_pull_bkrp_client_side_wrapped);
 	if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	if ((uncrypt_request.version != BACKUPKEY_CLIENT_WRAP_VERSION2)
@@ -629,14 +629,14 @@ static WERROR bkrp_client_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 
 	guid_string = GUID_string(mem_ctx, &uncrypt_request.guid);
 	if (guid_string == NULL) {
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 
 	cert_secret_name = talloc_asprintf(mem_ctx,
 					   "BCKUPKEY_%s",
 					   guid_string);
 	if (cert_secret_name == NULL) {
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 
 	status = get_lsa_secret(mem_ctx,
@@ -675,7 +675,7 @@ static WERROR bkrp_client_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 						    uncrypt_request.encrypted_secret_len);
 		if (reversed_secret.data == NULL) {
 			hx509_private_key_free(&pk);
-			return WERR_NOMEM;
+			return WERR_NOT_ENOUGH_MEMORY;
 		}
 
 		/* The secret has to be reversed ... */
@@ -829,7 +829,11 @@ static WERROR create_heimdal_rsa_key(TALLOC_CTX *ctx, hx509_context *hctx,
 
 	*rsa = NULL;
 
-	gnutls_global_init();
+	ret = gnutls_global_init();
+	if (ret != GNUTLS_E_SUCCESS) {
+		DBG_ERR("TLS error: %s\n", gnutls_strerror(ret));
+		return WERR_INTERNAL_ERROR;
+	}
 #if defined(HAVE_GCRYPT_H) && !defined(HAVE_GNUTLS3)
 	DEBUG(3,("Enabling QUICK mode in gcrypt\n"));
 	gcry_control(GCRYCTL_ENABLE_QUICK_RANDOM, 0);
@@ -863,7 +867,7 @@ static WERROR create_heimdal_rsa_key(TALLOC_CTX *ctx, hx509_context *hctx,
 
 	p0 = talloc_size(ctx, len);
 	if (p0 == NULL) {
-		werr = WERR_NOMEM;
+		werr = WERR_NOT_ENOUGH_MEMORY;
 		goto done;
 	}
 	p = p0;
@@ -945,7 +949,7 @@ static WERROR self_sign_cert(TALLOC_CTX *ctx, hx509_context *hctx, hx509_request
 
 	uniqueid.data = talloc_memdup(ctx, guidblob->data, guidblob->length);
 	if (uniqueid.data == NULL) {
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 	/* uniqueid is a bit string in which each byte represent 1 bit (1 or 0)
 	 * so as 1 byte is 8 bits we need to provision 8 times more space as in the
@@ -957,7 +961,7 @@ static WERROR self_sign_cert(TALLOC_CTX *ctx, hx509_context *hctx, hx509_request
 					    guidblob->length);
 	if (serialnumber.data == NULL) {
 		talloc_free(uniqueid.data);
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 
 	/* Native AD generates certificates with serialnumber in reversed notation */
@@ -1377,7 +1381,7 @@ static WERROR generate_bkrp_server_wrap_key(TALLOC_CTX *ctx, struct ldb_context
 	secret_name = talloc_asprintf(frame, "BCKUPKEY_%s", GUID_string(ctx, &guid));
 	if (secret_name == NULL) {
 		TALLOC_FREE(frame);
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 
 	status = set_lsa_secret(frame, ldb_ctx, secret_name, &blob_wrap_key);
@@ -1430,7 +1434,7 @@ static WERROR bkrp_do_retrieve_server_wrap_key(TALLOC_CTX *mem_ctx, struct ldb_c
 
 	secret_name = talloc_asprintf(mem_ctx, "BCKUPKEY_%s", guid_string);
 	if (secret_name == NULL) {
-		return WERR_NOMEM;
+		return WERR_NOT_ENOUGH_MEMORY;
 	}
 
 	status = get_lsa_secret(mem_ctx, ldb_ctx, secret_name, &lsa_secret);
@@ -1510,17 +1514,17 @@ static WERROR bkrp_server_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 	blob.length = r->in.data_in_len;
 
 	if (r->in.data_in_len == 0 || r->in.data_in == NULL) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	ndr_err = ndr_pull_struct_blob_all(&blob, mem_ctx, &decrypt_request,
 					   (ndr_pull_flags_fn_t)ndr_pull_bkrp_server_side_wrapped);
 	if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	if (decrypt_request.magic != BACKUPKEY_SERVER_WRAP_VERSION) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	werr = bkrp_do_retrieve_server_wrap_key(mem_ctx, ldb_ctx, &server_key,
@@ -1554,11 +1558,11 @@ static WERROR bkrp_server_wrap_decrypt_data(struct dcesrv_call_state *dce_call,
 	ndr_err = ndr_pull_struct_blob_all(&encrypted_blob, mem_ctx, &rc4payload,
 					   (ndr_pull_flags_fn_t)ndr_pull_bkrp_rc4encryptedpayload);
 	if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	if (decrypt_request.payload_length != rc4payload.secret_data.length) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	dump_data_pw("r3: \n", rc4payload.r3, sizeof(rc4payload.r3));
@@ -1618,7 +1622,7 @@ static WERROR bkrp_generic_decrypt_data(struct dcesrv_call_state *dce_call, TALL
 					struct bkrp_BackupKey *r, struct ldb_context *ldb_ctx)
 {
 	if (r->in.data_in_len < 4 || r->in.data_in == NULL) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	if (IVAL(r->in.data_in, 0) == BACKUPKEY_SERVER_WRAP_VERSION) {
@@ -1662,7 +1666,7 @@ static WERROR bkrp_server_wrap_encrypt_data(struct dcesrv_call_state *dce_call,
 	struct GUID guid;
 
 	if (r->in.data_in_len == 0 || r->in.data_in == NULL) {
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	werr = bkrp_do_retrieve_default_server_wrap_key(mem_ctx,
@@ -1790,7 +1794,7 @@ static WERROR bkrp_server_wrap_encrypt_data(struct dcesrv_call_state *dce_call,
 static WERROR dcesrv_bkrp_BackupKey(struct dcesrv_call_state *dce_call,
 				    TALLOC_CTX *mem_ctx, struct bkrp_BackupKey *r)
 {
-	WERROR error = WERR_INVALID_PARAM;
+	WERROR error = WERR_INVALID_PARAMETER;
 	struct ldb_context *ldb_ctx;
 	bool is_rodc;
 	const char *addr = "unknown";
@@ -1816,7 +1820,7 @@ static WERROR dcesrv_bkrp_BackupKey(struct dcesrv_call_state *dce_call,
 
 	if (samdb_rodc(ldb_ctx, &is_rodc) != LDB_SUCCESS) {
 		talloc_unlink(mem_ctx, ldb_ctx);
-		return WERR_INVALID_PARAM;
+		return WERR_INVALID_PARAMETER;
 	}
 
 	if (!is_rodc) {
